@@ -49,6 +49,6 @@ int main(int argc, char *argv[])
         QApplication::beep();
         QMessageBox::critical(0, QString::null,
                               QApplication::tr("You must run this program as normal user."));
-        return 1;
+        return EXIT_FAILURE;
     }
 }
